<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2019 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2019.2/1886137
 */

use Application\Factory\InvokableServiceFactory;
use Changes\Service\Change;
use Application\Config\Services;
use Application\Model\IModelDAO;
use Changes\Model\ChangeDAO;
use Changes\Service\ChangeComparator;

return [
    'router' => [
        'routes' => [
            'changes' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/changes?(/(?P<path>.*))?',
                    'spec'     => '/changes/%path%',
                    'defaults' => [
                        'controller' => Changes\Controller\IndexController::class,
                        'action'     => 'changes',
                        'path'       => null
                    ],
                ],
            ],
            'change' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/changes?(/(?P<change>[0-9]+))/?',
                    'spec'     => '/changes/%change%',
                    'defaults' => [
                        'controller' => Changes\Controller\IndexController::class,
                        'action'     => 'change',
                        'change'     => null
                    ],
                ],
            ],
            'change-fixes' => [
                'type' => 'Application\Router\Regex',
                'options' => [
                    'regex'    => '/changes?/(?P<change>[^/]+)/fixes(/(?P<mode>(add|delete)))?/?',
                    'spec'     => '/changes/%change%/fixes/%mode%',
                    'defaults' => [
                        'controller' => Changes\Controller\IndexController::class,
                        'action'     => 'fixes',
                        'change'     => null,
                        'mode'       => null
                    ],
                ],
            ],
        ],
    ],
    'controllers' => [
        'factories' => [
            Changes\Controller\IndexController::class => Application\Controller\IndexControllerFactory::class
        ],
    ],
    'view_manager' => [
        'template_map' => [
            'changes/index/index'  => __DIR__ . '/../view/changes/index/change.phtml',
        ],
        'template_path_stack'   => [
            __DIR__ . '/../view',
        ],
    ],
    'service_manager' => [
        'aliases' => [
            Services::CHANGE_SERVICE    => Change::class,
            Services::CHANGE_COMPARATOR => ChangeComparator::class,
            IModelDAO::CHANGE_DAO       => ChangeDAO::class
        ],
        'factories' => [
            Change::class           => InvokableServiceFactory::class,
            ChangeDAO::class        => InvokableServiceFactory::class,
            ChangeComparator::class => InvokableServiceFactory::class
        ],
    ],
];
